@@ -7,9 +7,9 @@
  * @date   2006-09-15
  * @brief  Exiv2 library interface for KDE
  *
- * @author Copyright (C) 2006-2012 by Gilles Caulier
+ * @author Copyright (C) 2006-2014 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
+ * @author Copyright (C) 2006-2013 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
  *
  * This program is free software; you can redistribute it
@@ -28,10 +28,16 @@
 #include "kexiv2.h"
 #include "kexiv2_p.h"
 
+// KDE includes
+
+#include <klibloader.h>
+
 // Local includes
 
 #include "version.h"
 
+static const KCatalogLoader loader("libkexiv2");
+
 namespace KExiv2Iface
 {
 
@@ -58,24 +64,24 @@ KExiv2Data& KExiv2Data::operator=(const KExiv2Data& other)
 // -------------------------------------------------------------------------------------------
 
 KExiv2::KExiv2()
-    : d(new KExiv2Priv)
+    : d(new Private)
 {
 }
 
 KExiv2::KExiv2(const KExiv2& metadata)
-    : d(new KExiv2Priv)
+    : d(new Private)
 {
     d->copyPrivateData(metadata.d);
 }
 
 KExiv2::KExiv2(const KExiv2Data& data)
-    : d(new KExiv2Priv)
+    : d(new Private)
 {
     setData(data);
 }
 
 KExiv2::KExiv2(const QString& filePath)
-    : d(new KExiv2Priv)
+    : d(new Private)
 {
     load(filePath);
 }
@@ -143,43 +149,23 @@ bool KExiv2::supportMetadataWritting(const QString& typeMime)
     }
     else if (typeMime == QString("image/tiff"))
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         return true;
-#else
-        return false;
-#endif
     }
     else if (typeMime == QString("image/png"))
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         return true;
-#else
-        return false;
-#endif
     }
     else if (typeMime == QString("image/jp2"))
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         return true;
-#else
-        return false;
-#endif
     }
     else if (typeMime == QString("image/x-raw"))
     {
-#if (EXIV2_TEST_VERSION(0,17,91))
         return true;
-#else
-        return false;
-#endif
     }
     else if (typeMime == QString("image/pgf"))
     {
-#if (EXIV2_TEST_VERSION(0,19,1))
         return true;
-#else
-        return false;
-#endif
     }
 
     return false;
@@ -190,13 +176,7 @@ QString KExiv2::Exiv2Version()
     // Since 0.14.0 release, we can extract run-time version of Exiv2.
     // else we return make version.
 
-#if (EXIV2_TEST_VERSION(0,14,0))
     return QString(Exiv2::version());
-#else
-    return QString("%1.%2.%3").arg(EXIV2_MAJOR_VERSION)
-                              .arg(EXIV2_MINOR_VERSION)
-                              .arg(EXIV2_PATCH_VERSION);
-#endif
 }
 
 QString KExiv2::version()
@@ -255,7 +235,7 @@ void KExiv2::setData(const KExiv2Data& data)
     else
     {
         // KExiv2Data can have a null pointer,
-        // but we never want a null pointer in KExiv2Priv.
+        // but we never want a null pointer in Private.
         d->data->clear();
     }
 }
@@ -303,6 +283,10 @@ bool KExiv2::loadFromData(const QByteArray& imgData) const
     {
         d->printExiv2ExceptionError("Cannot load metadata using Exiv2 ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
     return false;
 }
@@ -355,6 +339,10 @@ bool KExiv2::load(const QString& filePath) const
     {
         d->printExiv2ExceptionError("Cannot load metadata from file ", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
 
 #ifdef _XMP_SUPPORT_
     try
@@ -371,12 +359,8 @@ bool KExiv2::load(const QString& filePath) const
                 xmpsidecar = Exiv2::ImageFactory::open((const char*)QFile::encodeName(xmpSidecarPath));
                 xmpsidecar->readMetadata();
 
-                // Merge sidecar data to main XMP
-                d->mergeXmpData(xmpsidecar->xmpData(), d->xmpMetadata());
-                // Xmp.exif data from the sidecar is available from the exifData of the sidecar image;
-                // but we do not need to care for this, all reading methods check main Exif first,
-                // then Xmp.exif, so we have already implemented the correct reading algorithm.
-
+                // Merge
+                d->loadSidecarData(xmpsidecar);
                 hasLoaded = true;
             }
         }
@@ -385,6 +369,11 @@ bool KExiv2::load(const QString& filePath) const
     {
         d->printExiv2ExceptionError("Cannot load XMP sidecar", e);
     }
+    catch(...)
+    {
+        kError() << "Default exception from Exiv2";
+    }
+
 #endif // _XMP_SUPPORT_
 
     return hasLoaded;
@@ -416,7 +405,7 @@ bool KExiv2::save(const QString& imageFilePath) const
         regularFilePath = givenFileInfo.canonicalPath();// Walk all the symlinks
     }
 
-    // NOTE: see B.K.O #137770 & #138540 : never touch the file if is read only.
+    // NOTE: see bug #137770 & #138540 : never touch the file if is read only.
     QFileInfo finfo(regularFilePath);
     QFileInfo dinfo(finfo.path());
     if (!dinfo.isWritable())
@@ -425,7 +414,7 @@ bool KExiv2::save(const QString& imageFilePath) const
         return false;
     }
 
-    bool writeToFile                     = false; 
+    bool writeToFile                     = false;
     bool writeToSidecar                  = false;
     bool writeToSidecarIfFileNotPossible = false;
     bool writtenToFile                   = false;
